@@ -5,25 +5,30 @@ from sqlalchemy import text
 import pandas as pd
 import sqlalchemy
 import aiofiles
+import inspect
 import asyncio
 import os
 
 engine_manager = EngineManager()
 
-"""Converts SQLAlchemy query results into a pandas DataFrame.
-
-Args:
-    query_output (ResultProxy): SQLAlchemy query output.
-
-Returns:
-    pd.DataFrame: DataFrame containing the query results.
 """
+    Converts SQLAlchemy query results into a pandas DataFrame.
+
+    Args:
+        query_output (ResultProxy): SQLAlchemy query output.
+
+    Returns:
+        pd.DataFrame: DataFrame containing the query results.
+    """
 async def format_to_df(query_output):
-    # Fetch rows and column names concurrently
-    rows, columns_name = await asyncio.gather(
-        query_output.fetchall(),
-        query_output.keys()
-    )
+    if inspect.iscoroutinefunction(query_output.fetchall):
+        rows, columns_name = await asyncio.gather(
+            query_output.fetchall(),
+            query_output.keys()
+        )
+    else:
+        rows = query_output.fetchall()
+        columns_name = query_output.keys()
     return pd.DataFrame(rows, columns=columns_name)
 
 """Executes a SQL query and optionally backs up a specified table.
